# Keras Efficient Kan 

Keras package reproducting the pytorch [efficient_kan implementation](https://github.com/Blealtan/efficient-kan)

Package is available on pypi [here](https://pypi.org/project/keras-efficient-kan/)

It implements KANLinear based on [Kolmogorov-Arnold Network](https://arxiv.org/abs/2404.19756) that can be used as a drop-in replacement for Dense layers in Keras models.

It supports array with more than 2 dimensions, applying the same transformation to all the dimensions except the last one.


Shield: [![CC BY-NC-SA 4.0][cc-by-nc-sa-shield]][cc-by-nc-sa]

This work is licensed under a
[Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License][cc-by-nc-sa].

[![CC BY-NC-SA 4.0][cc-by-nc-sa-image]][cc-by-nc-sa]

[cc-by-nc-sa]: http://creativecommons.org/licenses/by-nc-sa/4.0/
[cc-by-nc-sa-image]: https://licensebuttons.net/l/by-nc-sa/4.0/88x31.png
[cc-by-nc-sa-shield]: https://img.shields.io/badge/License-CC%20BY--NC--SA%204.0-lightgrey.svg
